# NiemaFS
Niema's Python library for reading data from various file system standards

## Installation
NiemaFS can be installed using `pip`:

```bash
sudo pip install niemafs
```

If you are using a machine on which you lack administrative powers, NiemaFS can be installed locally using `pip`:

```bash
pip install --user niemafs
```

## Usage
Example usage will be added in the near future. For now, refer to the [documentation](https://niema.net/NiemaFS) as well as the [example scripts](example).
